@@ -9,6 +9,6 @@
 #ifndef XPLOT_MAPS_CONFIG_HPP
 #define XPLOT_MAPS_CONFIG_HPP
 
-#define XPLOT_MAPS_DIR "C:/bld/xplot_1563522637519/_h_env/Library/share/xplot/map_data/"
+#define XPLOT_MAPS_DIR "D:/bld/xplot_1579711110659/_h_env/Library/share/xplot/map_data/"
 
 #endif
