@@ -9,7 +9,7 @@
 #ifndef XPLOT_CONFIG_CLING_HPP
 #define XPLOT_CONFIG_CLING_HPP
 
-#pragma cling add_library_path("C:/bld/xplot_1563522637519/_h_env/Library/lib")
+#pragma cling add_library_path("D:/bld/xplot_1579711110659/_h_env/Library/lib")
 #pragma cling load("libxplot")
 
 #endif
